package initialize

import (
	"go.uber.org/zap"
	"gorm.io/gorm"
	"os"
	"server/dao"
	"server/global"
	"server/model/example"
)

func Gorm() *gorm.DB {
	switch global.GVA_CONFIG.System.DbType {
	case "mysql":
		return GormMysql()
	case "pgsql":
		return GormPgSql()
	case "oracle":
		return GormOracle()
	case "mssql":
		return GormMssql()
	case "sqlite":
		return GormSqlite()
	default:
		return GormMysql()
	}
}

func RegisterTables() {
	db := global.GVA_DB
	err := db.AutoMigrate(

		dao.SysApi{},
		dao.SysUser{},
		dao.SysBaseMenu{},
		dao.JwtBlacklist{},
		dao.SysAuthority{},
		dao.SysDictionary{},
		dao.SysOperationRecord{},
		dao.SysDictionaryDetail{},
		dao.SysBaseMenuParameter{},
		dao.SysBaseMenuBtn{},
		dao.SysAuthorityBtn{},

		example.ExaFile{},
		example.ExaFileChunk{},
		dao.ExaFileUploadAndDownload{},

		dao.Region{},
		dao.Tunnel{},
		dao.TunnelTime{},
		dao.Device{},
		dao.DeviceGenre{},
		dao.DeviceRelay{},
		dao.EnvData{},
		dao.OpticalData{},
	)
	if err != nil {
		global.GVA_LOG.Error("register table failed", zap.Error(err))
		os.Exit(0)
	}
	global.GVA_LOG.Info("register table success")
}
